@@ -11,4 +11,6 @@ def _getcsv(name):
 countries = _getcsv('countries')
 airbnb = _getcsv('airbnb')
 corona = _getcsv('corona')
-drinks = _getcsv('drinks')
\ No newline at end of file
+drinks = _getcsv('drinks')
+titanic = _getcsv('titanic')
+iris = _getcsv('iris')
\ No newline at end of file
